@@ -1,7 +1,7 @@
 #ifndef IL_ERROR_H
 #define IL_ERROR_H
 
-#ident "$Header: /cvs/jra1mw/org.glite.lb.logger/interface/il_error.h,v 1.1 2010/06/07 09:02:06 mvocu Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -40,7 +40,7 @@ struct error_inf {
 };
 
 int init_errors();
-int set_error(int, long, char *);
+int set_error(int, long, const char *);
 int clear_error();
 int error_get_maj();
 long error_get_min();
