@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/glite/org.glite.lb.logger/src/il_error.c,v 1.13 2013/01/31 16:31:22 mvocu Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -106,7 +106,7 @@ init_errors()
 }
 
 int 
-set_error(int code, long minor, char *msg)
+set_error(int code, long minor, const char *msg)
 {
   struct error_inf *err;
   char buf[256];
